<?php
declare(strict_types=1);

namespace App\Validator;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;
use Symfony\Component\Validator\Exception\UnexpectedValueException;

class MoneyValidator extends ConstraintValidator {
    public function validate(mixed $value, Constraint $constraint): void
    {
        if (!$constraint instanceof Money) {
            throw new UnexpectedTypeException($constraint, Money::class);
        }

        if (null === $value || '' === $value) {
            return ;
        }

        if (is_string($value) === false) {
            throw new UnexpectedValueException($value, "string");
        }

        if (preg_match('/^\d+([\.,]\d{0,2})?$/', $value)) {
            return ;
        }

        $this->context->buildViolation($constraint->message)
            ->setParameter('{{ string }}', $value)
            ->addViolation();
    }
}
